@@ -595,9 +595,9 @@ class Environment(object):
     def open_db(self, name=None, txn=None, reverse_key=False, dupsort=False,
             create=True):
         """
-        Open a database, returning an opaque handle. Repeat :py:meth:`open_db`
-        calls for the same name will return the same handle. As a special case,
-        the main database is always open.
+        Open a database, returning an opaque handle. Repeat
+        :py:meth:`Environment.open_db` calls for the same name will return the
+        same handle. As a special case, the main database is always open.
 
         Equivalent to `mdb_dbi_open()
         <http://symas.com/mdb/doc/group__mdb.html#gac08cad5b096925642ca359a6d6f0562a>`_
@@ -655,9 +655,9 @@ class Environment(object):
         self._dbs[name] = weakref.ref(db)
         return db
 
-    def begin(self, **kwargs):
+    def begin(self, db=None, parent=None, write=False, buffers=False):
         """Shortcut for :py:class:`lmdb.Transaction`"""
-        return Transaction(self, **kwargs)
+        return Transaction(self, db, parent, write, buffers)
 
     def get(self, key, default=None, db=None):
         """Use a temporary read transaction to invoke
@@ -1029,7 +1029,7 @@ class Cursor(object):
             ...     for i, (key, value) in enumerate(txn.cursor().iterprev()):
             ...         print '%dth last item is (%r, %r)' % (1 + i, key, value)
 
-    Both :py:meth:`forward` and :py:meth:`reverse` accept `keys` and `values`
+    Both :py:meth:`iternext` and :py:meth:`iterprev` accept `keys` and `values`
     arguments. If both are ``True``, then the value of :py:meth:`item` is
     yielded on each iteration. If only `keys` is ``True``, :py:meth:`key` is
     yielded, otherwise only :py:meth:`value` is yielded.
@@ -1050,7 +1050,7 @@ class Cursor(object):
     inefficient code. In cases where the iteration order is not obvious, or is
     related to the data being read, use of :py:meth:`set_key`,
     :py:meth:`set_range`, :py:meth:`key`, :py:meth:`value`, and :py:meth:`item`
-    are often preferable:
+    may be preferable:
 
         ::
 
@@ -1245,7 +1245,7 @@ class Cursor(object):
         return default
 
     def set_range(self, key):
-        """Seek to the first key greater than or equal `key`, returning
+        """Seek to the first key greater than or equal to `key`, returning
         ``True`` on success, or ``False`` to indicate key was past end of
         database.
 
@@ -1290,7 +1290,7 @@ class Cursor(object):
 
     def put(self, key, val, dupdata=False, overwrite=True, append=False):
         """Store a record, returning ``True`` if it was written, or ``False``
-        to indicate the key was already present and `override=False`. On
+        to indicate the key was already present and `overwrite=False`. On
         success, the cursor is positioned on the key.
 
         Equivalent to `mdb_cursor_put()
